@@ -25,20 +25,20 @@ sub valid_args {
             expected => "<DEFAULT>",
             args => [ 'Prompt: ', { no_echo => 1, default => "DEFAULT" } ],
         },
-        #{
-        #    expected => "<123>",
-        #    args => [ "Prompt: ", { no_echo => 2, default => 123 } ],
-        #},
+        {
+            expected => "<123>",
+            args => [ "Prompt: ", { no_echo => 2, default => '123' } ],
+        },
+        {
+            expected => "<123>",
+            args => [ "Prompt: ", { no_echo => 2, default => 123 } ],
+        },
     ];
 }
 
 
 sub invalid_args {
     return [
-        #{
-        #    expected => "<>",
-        #    args => [],
-        #},
         {
             expected => "<readline: a reference is not a valid prompt.>",
             args => [ {} ],
